Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1920)

Unified Diff: chrome/browser/geolocation/geolocation_permission_context_android.h

Issue 815343005: Clean up geolocation code now that it's all upstream. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: renamed IsSystemLocationEnabled -> IsLocationEnabled Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/geolocation/geolocation_permission_context_android.h
diff --git a/chrome/browser/geolocation/geolocation_permission_context_android.h b/chrome/browser/geolocation/geolocation_permission_context_android.h
index 73c6cbdc4fd77a19f9989c684b33731d723c4ebd..db24bfbe2d1cf1ff7322c05c8ca44ae4725932d5 100644
--- a/chrome/browser/geolocation/geolocation_permission_context_android.h
+++ b/chrome/browser/geolocation/geolocation_permission_context_android.h
@@ -27,7 +27,7 @@ namespace content {
class WebContents;
}
-class GoogleLocationSettingsHelper;
+class LocationSettings;
class GURL;
class PermissionRequestID;
@@ -48,12 +48,11 @@ class GeolocationPermissionContextAndroid
bool user_gesture,
const BrowserPermissionCallback& callback) override;
// Overrides the GoogleLocationSettingsHelper used to determine whether
// system and Chrome-wide location permissions are enabled.
- void SetGoogleLocationSettingsHelperForTesting(
- scoped_ptr<GoogleLocationSettingsHelper> helper);
+ void SetLocationSettingsForTesting(scoped_ptr<LocationSettings> settings);
- scoped_ptr<GoogleLocationSettingsHelper> google_location_settings_helper_;
+ scoped_ptr<LocationSettings> location_settings_;
DISALLOW_COPY_AND_ASSIGN(GeolocationPermissionContextAndroid);
};
« no previous file with comments | « chrome/browser/android/mock_location_settings.cc ('k') | chrome/browser/geolocation/geolocation_permission_context_android.cc » ('j') | no next file with comments »
@@ -48,12 +48,11 @@ class GeolocationPermissionContextAndroid
bool user_gesture,
const BrowserPermissionCallback& callback) override;
- // Overrides the GoogleLocationSettingsHelper used to determine whether
+ // Overrides the LocationSettings object used to determine whether
// system and Chrome-wide location permissions are enabled.

Powered by Google App Engine
This is Rietveld 408576698